@@ -15,6 +15,7 @@
 #define QABSTRACT3DINPUTHANDLER_P_H
 
 #include "qabstract3dinputhandler.h"
+#include "qquickgraphsitem_p.h"
 
 QT_BEGIN_NAMESPACE
 
@@ -31,16 +32,16 @@ public:
     ~QAbstract3DInputHandlerPrivate();
 
 public:
-    enum InputState {
-        InputStateNone = 0,
-        InputStateSelecting,
-        InputStateRotating,
-        InputStatePinching
+    enum class InputState {
+        None = 0,
+        Selecting,
+        Rotating,
+        Pinching
     };
 
     int m_prevDistance = 0;
     QPoint m_previousInputPos = {};
-    InputState m_inputState = InputStateNone;
+    InputState m_inputState = InputState::None;
 
 protected:
     QAbstract3DInputHandler *q_ptr;
@@ -50,6 +51,7 @@ private:
     QPoint m_inputPosition;
 
     Q3DScene *m_scene;
+    QQuickGraphsItem *m_item;
     bool m_isDefaultHandler;
 
     friend class QQuickGraphsItem;
