@@ -26,6 +26,7 @@ int main(int argc, char **argv)
     graph->setMaximumSize(screenSize);
     graph->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
     graph->setFocusPolicy(Qt::StrongFocus);
+    graph->setResizeMode(QQuickWidget::SizeRootObjectToView);
 
     QWidget *widget = new QWidget;
     QHBoxLayout *hLayout = new QHBoxLayout(widget);
@@ -38,7 +39,6 @@ int main(int argc, char **argv)
     QComboBox *themeList = new QComboBox(widget);
     themeList->addItem(QStringLiteral("Qt"));
     themeList->addItem(QStringLiteral("Primary Colors"));
-    themeList->addItem(QStringLiteral("Digia"));
     themeList->addItem(QStringLiteral("Stone Moss"));
     themeList->addItem(QStringLiteral("Army Blue"));
     themeList->addItem(QStringLiteral("Retro"));
@@ -50,9 +50,9 @@ int main(int argc, char **argv)
     labelButton->setText(QStringLiteral("Change label style"));
 
     QComboBox *itemStyleList = new QComboBox(widget);
-    itemStyleList->addItem(QStringLiteral("Arrow"), int(QAbstract3DSeries::MeshArrow));
-    itemStyleList->addItem(QStringLiteral("Cube"), int(QAbstract3DSeries::MeshCube));
-    itemStyleList->addItem(QStringLiteral("Minimal"), int(QAbstract3DSeries::MeshMinimal));
+    itemStyleList->addItem(QStringLiteral("Arrow"), int(QAbstract3DSeries::Mesh::Arrow));
+    itemStyleList->addItem(QStringLiteral("Cube"), int(QAbstract3DSeries::Mesh::Cube));
+    itemStyleList->addItem(QStringLiteral("Minimal"), int(QAbstract3DSeries::Mesh::Minimal));
     itemStyleList->setCurrentIndex(-1);
 
     QPushButton *cameraButton = new QPushButton(widget);
